@@ -2,7 +2,7 @@ import torch
 import cupy as cp
 import numpy as np
 import math
-from .CustomKernel import CustomKernel, Stream
+from .CustomKernel import CustomKernel
 from torchpq.util import get_absolute_path
 
 class ComputeCentroidsCUDA(CustomKernel):
@@ -12,13 +12,12 @@ class ComputeCentroidsCUDA(CustomKernel):
       dk=16,
       sm_size=48*256*4,
     ):
+    super(ComputeCentroidsCUDA, self).__init__()
     self.de = de
     self.dk = dk
     assert dk * (de + 1) * 4 <= sm_size
     self.tpb = 256
     self.sm_size = sm_size
-    self._use_torch_in_cupy_malloc()
-    self.stream = Stream(torch.cuda.current_stream().cuda_stream)
 
     with open(get_absolute_path("kmeans", "kernels", "ComputeCentroidsKernel.cu"), "r") as f:
       self.kernel = f.read()
